@@ -23,7 +23,7 @@ import runner1c.exit_code
 
 def create_base_if_necessary(func):
     def wrapper(self):
-        if getattr(self.arguments, 'connection', False):
+        if not self.need_connection or getattr(self.arguments, 'connection', False):
             return func(self)
         else:
             temp_folder = tempfile.mkdtemp()
@@ -78,7 +78,7 @@ class Command(abc.ABC):
         return runner1c.exit_code.EXIT_CODE.error
 
     @property
-    def add_key_for_connection(self):
+    def need_connection(self):
         return True
 
     def execute(self):
@@ -111,7 +111,7 @@ class Command(abc.ABC):
         setattr(p_agent, 'folder', self.arguments.folder)
         setattr(p_agent, 'port', port_agent)
         StartAgent(arguments=p_agent).execute()
-        time.sleep(1)
+        time.sleep(3)
 
         # noinspection PyAttributeOutsideInit
         self._agent_started = True
@@ -391,15 +391,15 @@ class Command(abc.ABC):
             setattr(self.arguments, 'external_result', False)
 
     def _set_connection_string(self):
-        if self.add_key_for_connection:
+        if isinstance(self, CreateBase):
+            setattr(self.arguments, 'connection_string', '"{}"'.format(self.arguments.connection))
+        else:
             if self.arguments.connection.endswith('v8i'):
                 type_connection = 'RunShortcut'
             else:
                 type_connection = 'IBConnectionString'
             setattr(self.arguments, 'connection_string',
                     '/{} "{}"'.format(type_connection, self.arguments.connection))
-        else:
-            setattr(self.arguments, 'connection_string', '"{}"'.format(self.arguments.connection))
 
     def _set_path_1c(self):
         if getattr(self.arguments, 'path', False):
@@ -407,9 +407,12 @@ class Command(abc.ABC):
         else:
             path = common.get_path_to_max_version_1c()
 
-        file_name_1c = '1cv8.exe'
-        if self._mode == Mode.ENTERPRISE and not getattr(self.arguments, 'thick', False):
+        if self._mode == Mode.WEBINST:
+            file_name_1c = 'webinst.exe'
+        elif self._mode == Mode.ENTERPRISE and not getattr(self.arguments, 'thick', False):
             file_name_1c = '1cv8c.exe'
+        else:
+            file_name_1c = '1cv8.exe'
 
         setattr(self.arguments, 'path_1c_exe', os.path.join(path, file_name_1c))
 
@@ -446,6 +449,7 @@ class Mode(Enum):
     DESIGNER = 'DESIGNER'
     ENTERPRISE = 'ENTERPRISE'
     CREATE = 'CREATEINFOBASE'
+    WEBINST = 'WEBINST'
 
 
 class EmptyParameters:
@@ -468,10 +472,6 @@ class CreateBase(Command):
         kwargs['mode'] = Mode.CREATE
         super().__init__(**kwargs)
 
-    @property
-    def add_key_for_connection(self):
-        return False
-
 
 class StartAgent(Command):
     def __init__(self, **kwargs):
